==> calendar-v1.7.21.zip: calendar/messages/el/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Προσθήκη</strong> ημερολογίου προφίλ',
    '<strong>Choose</strong> target calendar' => '<strong>Επιλέξτε</strong> στοχευόμενο ημερολόγιο',
    '<strong>Reminder</strong> settings' => 'Ρυθμίσεις <strong>Υπενθυμίσεων</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Προσθέτει ημερολόγιο για ιδιωτικά ή δημόσια συμβάντα στο προφίλ σας και στο κύριο μενού.',
    'Adds an event calendar to this space.' => 'Προσθέτει ένα ημερολόγιο εκδηλώσεων σε αυτόν τον χώρο.',
    'After (occurrences)' => 'Μετά (εμφανίσεις)',
    'All Day' => 'Όλη μέρα',
    'Allows the user to create new calendar entries' => 'Επιτρέπει στον χρήστη τη δημιουργία νέων καταχωρήσεων ημερολογίου',
    'Allows the user to edit/delete existing calendar entries' => 'Επιτρέπει στον χρήστη να επεξεργάζεται/διαγράφει τις υπάρχουσες καταχωρήσεις ημερολογίου',
    'Attending' => 'Συμμετοχή',
    'Birthday' => 'Γενέθλια',
    'Calendar' => 'Ημερολόγιο',
    'Cancel Event' => 'Ακύρωση Εκδήλωσης',
    'Create entry' => 'Δημιουργία καταχώρησης',
    'Custom reminder' => 'Προσαρμοσμένη υπενθύμιση',
    'Day' => 'Ημέρα',
    'Days' => 'Ημέρες',
    'Default reminder settings' => 'Προεπιλεγμένες ρυθμίσεις υπενθύμισης',
    'Delete all events' => 'Διαγραφή όλων των συμβάντων',
    'Description' => 'Περιγραφή',
    'Do you want to install this module on your profile?' => 'Θέλετε να εγκαταστήσετε αυτήν την ενότητα στο προφίλ σας;',
    'Edit' => 'Επεξεργασία',
    'Edit all events' => 'Επεξεργασία όλων των συμβάντων',
    'Edit this and following events' => 'Επεξεργαστείτε αυτό και τα επόμενα συμβάντα',
    'Edit this event' => 'Επεξεργαστείτε αυτό το συμβάν',
    'Enable' => 'Ενεργοποίηση',
    'End' => 'Τέλος',
    'End Date' => 'Ημερομηνία λήξης',
    'End Time' => 'Ώρα Λήξης',
    'End time must be after start time!' => 'Η ώρα λήξης πρέπει να είναι μετά την ώρα έναρξης!',
    'Event' => 'Εκδήλωση',
    'Event Type' => 'Τύπος Εκδήλωσης',
    'Event Types' => 'Τύποι εκδηλώσεων',
    'Event not found!' => 'Η εκδήλωση δεν βρέθηκε!',
    'Files' => 'Αρχεία',
    'Friday' => 'Παρασκευή',
    'Here you can configure default settings for all calendar events.' => 'Εδώ μπορείτε να ρυθμίσετε τις προεπιλεγμένες ρυθμίσεις για όλα τα συμβάντα ημερολογίου.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Εδώ μπορείτε να ρυθμίσετε τις προεπιλεγμένες υπενθυμίσεις για προεπιλογή. Αυτές οι ρυθμίσεις μπορούν να αντικατασταθούν στο επίπεδο χώρου / προφίλ.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Εδώ μπορείτε να ρυθμίσετε τις προεπιλεγμένες ρυθμίσεις υπενθύμισης για αυτό το συμβάν. Οι χρήστες μπορούν να αντικαταστήσουν αυτές τις ρυθμίσεις με τη σύνδεση <strong> Ορισμός υπενθύμισης </strong>.',
    'Hour' => 'Ωρα',
    'I\'m attending' => 'Παρακολουθώ',
    'ID' => 'Ταυτότητα',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Για να προσθέσετε συμβάντα στο προφίλ σας, πρέπει πρώτα να ενεργοποιήσετε τη μονάδα ημερολογίου.',
    'Interested' => 'Ενδιαφέρον',
    'Invalid date or time format!' => 'Μη έγκυρη μορφή ημερομηνίας ή ώρας!',
    'Invalid day of month given' => 'Μη έγκυρη ημέρα του μήνα',
    'Invalid event type id selected.' => 'Επιλέχθηκε μη έγκυρος τύπος ταυτότητας εκδήλωσης.',
    'Invalid frequency given' => 'Έχει δοθεί μη έγκυρη συχνότητα',
    'Invalid interval given' => 'Έχει δοθεί μη έγκυρο διάστημα',
    'Invalid week day selection' => 'Μη έγκυρη επιλογή ημέρας εβδομάδας',
    'Invite' => 'Προσκάλεσε',
    'Location' => 'Τοποθεσία',
    'Manage entries' => 'Διαχείριση καταχωρήσεων',
    'Maximum number of participants' => 'Μέγιστος αριθμός συμμετεχόντων',
    'Monday' => 'Δευτέρα',
    'Month' => 'Μήνας',
    'Monthly on day {dayOfMonth}' => 'Μηνιαία την ημέρα {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Μηνιαία στην {θέση} {dayOfWeek}',
    'Months' => 'Μήνες',
    'Never' => 'Ποτέ',
    'Next' => 'Επόμενο',
    'No reminder' => 'Χωρίς υπενθύμιση',
    'On date' => 'Τη μέρα',
    'Participants' => 'Συμμετέχοντες',
    'Profile Calendar' => 'Προφίλ Ημερολογίου',
    'Public' => 'Δημόσιο',
    'Recurring' => 'Επαναλαμβανόμενο',
    'Reopen Event' => 'Εκ νέου Άνοιγμα Εκδήλωσης',
    'Repeat every' => 'Επαναλάβετε κάθε',
    'Saturday' => 'Σάββατο',
    'Set reminder' => 'Ορισμός υπενθύμισης',
    'Sorting' => 'Ταξινόμηση',
    'Start Date' => 'Ημερομηνία έναρξης',
    'Start Time' => 'Ωρα έναρξης',
    'Sunday' => 'Κυριακή',
    'This event does not support recurrent events' => 'Αυτό το γεγονός δεν υποστηρίζει επαναλαμβανόμενα συμβάντα',
    'Thursday' => 'Πέμπτη',
    'Time Zone' => 'Ζώνη Ώρας',
    'Title' => 'Τίτλος',
    'Tuesday' => 'Τρίτη',
    'Upcoming {type}' => 'Προσεχές {type}',
    'Upcoming {type}: {title}' => 'Προσεχές {type}: {title}',
    'Use default reminder' => 'Χρήση προεπιλεγμένης υπενθύμισης',
    'User birthdays' => 'Γενέθλια Χρηστών',
    'Wednesday' => 'Τετάρτη',
    'Week' => 'Εβδομάδα',
    'Weeks' => 'Εβδομάδες',
    'Year' => 'Ετος',
    'Years' => 'Χρόνια',
    'You don\'t have permission to delete this event!' => 'Δεν έχετε δικαίωμα να διαγράψετε αυτή την εκδήλωση!',
    'You have an <strong>{type}</strong> coming up' => 'Έχεις <strong>{type}</strong> που έρχεται',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Έχεις <strong>{type}</strong> που έρχεται: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Ρυθμίσεις υπενθύμισης σας για το συμβάν: <strong>\'{title}\'</strong>',
    'canceled' => 'ακυρώθηκε',
    'disabled' => 'άτομα με ειδικές ανάγκες',
    'first' => 'πρώτα',
    'forth' => 'Εμπρός',
    'last' => 'τελευταίο',
    'on weekdays' => 'τις καθημερινές',
    'second' => 'δεύτερο',
    'third' => 'τρίτο',
    '{displayName} Birthday' => 'Γενέθλια του χρήστη {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => 'Ο/Η {displayName} μόλις σας πρόσθεσε στην εκδήλωση "{contentTitle}" του χώρου  {spaceName} ξεκινώντας από {time}.',
    '{displayName} added you to the event "{contentTitle}".' => 'Ο/η {displayName} Μόλις σας πρόσθεσε στην εκδήλωση "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Deleted' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Email' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'List' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Today' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/el/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Προσθήκη</strong> ημερολογίου προφίλ',
    '<strong>Choose</strong> target calendar' => '<strong>Επιλέξτε</strong> στοχευόμενο ημερολόγιο',
    '<strong>Reminder</strong> settings' => 'Ρυθμίσεις <strong>Υπενθυμίσεων</strong>',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Προσθέτει ημερολόγιο για ιδιωτικά ή δημόσια συμβάντα στο προφίλ σας και στο κύριο μενού.',
    'Adds an event calendar to this space.' => 'Προσθέτει ένα ημερολόγιο εκδηλώσεων σε αυτόν τον χώρο.',
    'After (occurrences)' => 'Μετά (εμφανίσεις)',
    'All Day' => 'Όλη μέρα',
    'Allows the user to create new calendar entries' => 'Επιτρέπει στον χρήστη τη δημιουργία νέων καταχωρήσεων ημερολογίου',
    'Allows the user to edit/delete existing calendar entries' => 'Επιτρέπει στον χρήστη να επεξεργάζεται/διαγράφει τις υπάρχουσες καταχωρήσεις ημερολογίου',
    'Attending' => 'Συμμετοχή',
    'Birthday' => 'Γενέθλια',
    'Calendar' => 'Ημερολόγιο',
    'Cancel Event' => 'Ακύρωση Εκδήλωσης',
    'Create entry' => 'Δημιουργία καταχώρησης',
    'Custom reminder' => 'Προσαρμοσμένη υπενθύμιση',
    'Day' => 'Ημέρα',
    'Days' => 'Ημέρες',
    'Default reminder settings' => 'Προεπιλεγμένες ρυθμίσεις υπενθύμισης',
    'Delete all events' => 'Διαγραφή όλων των συμβάντων',
    'Description' => 'Περιγραφή',
    'Do you want to install this module on your profile?' => 'Θέλετε να εγκαταστήσετε αυτήν την ενότητα στο προφίλ σας;',
    'Edit' => 'Επεξεργασία',
    'Edit all events' => 'Επεξεργασία όλων των συμβάντων',
    'Edit this and following events' => 'Επεξεργαστείτε αυτό και τα επόμενα συμβάντα',
    'Edit this event' => 'Επεξεργαστείτε αυτό το συμβάν',
    'Enable' => 'Ενεργοποίηση',
    'End' => 'Τέλος',
    'End Date' => 'Ημερομηνία λήξης',
    'End Time' => 'Ώρα Λήξης',
    'End time must be after start time!' => 'Η ώρα λήξης πρέπει να είναι μετά την ώρα έναρξης!',
    'Event' => 'Εκδήλωση',
    'Event Type' => 'Τύπος Εκδήλωσης',
    'Event Types' => 'Τύποι εκδηλώσεων',
    'Event not found!' => 'Η εκδήλωση δεν βρέθηκε!',
    'Files' => 'Αρχεία',
    'Friday' => 'Παρασκευή',
    'Here you can configure default settings for all calendar events.' => 'Εδώ μπορείτε να ρυθμίσετε τις προεπιλεγμένες ρυθμίσεις για όλα τα συμβάντα ημερολογίου.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Εδώ μπορείτε να ρυθμίσετε τις προεπιλεγμένες υπενθυμίσεις για προεπιλογή. Αυτές οι ρυθμίσεις μπορούν να αντικατασταθούν στο επίπεδο χώρου / προφίλ.',
    'Hour' => 'Ωρα',
    'I\'m attending' => 'Παρακολουθώ',
    'ID' => 'Ταυτότητα',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Για να προσθέσετε συμβάντα στο προφίλ σας, πρέπει πρώτα να ενεργοποιήσετε τη μονάδα ημερολογίου.',
    'Interested' => 'Ενδιαφέρον',
    'Invalid date or time format!' => 'Μη έγκυρη μορφή ημερομηνίας ή ώρας!',
    'Invalid day of month given' => 'Μη έγκυρη ημέρα του μήνα',
    'Invalid event type id selected.' => 'Επιλέχθηκε μη έγκυρος τύπος ταυτότητας εκδήλωσης.',
    'Invalid frequency given' => 'Έχει δοθεί μη έγκυρη συχνότητα',
    'Invalid interval given' => 'Έχει δοθεί μη έγκυρο διάστημα',
    'Invalid week day selection' => 'Μη έγκυρη επιλογή ημέρας εβδομάδας',
    'Invite' => 'Προσκάλεσε',
    'Location' => 'Τοποθεσία',
    'Manage entries' => 'Διαχείριση καταχωρήσεων',
    'Maximum number of participants' => 'Μέγιστος αριθμός συμμετεχόντων',
    'Monday' => 'Δευτέρα',
    'Month' => 'Μήνας',
    'Monthly on day {dayOfMonth}' => 'Μηνιαία την ημέρα {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Μηνιαία στην {θέση} {dayOfWeek}',
    'Months' => 'Μήνες',
    'Never' => 'Ποτέ',
    'Next' => 'Επόμενο',
    'No reminder' => 'Χωρίς υπενθύμιση',
    'On date' => 'Τη μέρα',
    'Participants' => 'Συμμετέχοντες',
    'Profile Calendar' => 'Προφίλ Ημερολογίου',
    'Public' => 'Δημόσιο',
    'Recurring' => 'Επαναλαμβανόμενο',
    'Reopen Event' => 'Εκ νέου Άνοιγμα Εκδήλωσης',
    'Repeat every' => 'Επαναλάβετε κάθε',
    'Saturday' => 'Σάββατο',
    'Set reminder' => 'Ορισμός υπενθύμισης',
    'Sorting' => 'Ταξινόμηση',
    'Start Date' => 'Ημερομηνία έναρξης',
    'Start Time' => 'Ωρα έναρξης',
    'Sunday' => 'Κυριακή',
    'This event does not support recurrent events' => 'Αυτό το γεγονός δεν υποστηρίζει επαναλαμβανόμενα συμβάντα',
    'Thursday' => 'Πέμπτη',
    'Time Zone' => 'Ζώνη Ώρας',
    'Title' => 'Τίτλος',
    'Tuesday' => 'Τρίτη',
    'Upcoming {type}' => 'Προσεχές {type}',
    'Upcoming {type}: {title}' => 'Προσεχές {type}: {title}',
    'Use default reminder' => 'Χρήση προεπιλεγμένης υπενθύμισης',
    'User birthdays' => 'Γενέθλια Χρηστών',
    'Wednesday' => 'Τετάρτη',
    'Week' => 'Εβδομάδα',
    'Weeks' => 'Εβδομάδες',
    'Year' => 'Ετος',
    'Years' => 'Χρόνια',
    'You don\'t have permission to delete this event!' => 'Δεν έχετε δικαίωμα να διαγράψετε αυτή την εκδήλωση!',
    'You have an <strong>{type}</strong> coming up' => 'Έχεις <strong>{type}</strong> που έρχεται',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Έχεις <strong>{type}</strong> που έρχεται: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'Ρυθμίσεις υπενθύμισης σας για το συμβάν: <strong>\'{title}\'</strong>',
    'canceled' => 'ακυρώθηκε',
    'disabled' => 'άτομα με ειδικές ανάγκες',
    'first' => 'πρώτα',
    'forth' => 'Εμπρός',
    'last' => 'τελευταίο',
    'on weekdays' => 'τις καθημερινές',
    'second' => 'δεύτερο',
    'third' => 'τρίτο',
    '{displayName} Birthday' => 'Γενέθλια του χρήστη {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => 'Ο/Η {displayName} μόλις σας πρόσθεσε στην εκδήλωση "{contentTitle}" του χώρου  {spaceName} ξεκινώντας από {time}.',
    '{displayName} added you to the event "{contentTitle}".' => 'Ο/η {displayName} Μόλις σας πρόσθεσε στην εκδήλωση "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cannot remove the participant!' => '',
    'Deleted' => '',
    'Display events within the next X days' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Email' => '',
    'Enable Reminder' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'List' => '',
    'Minute' => '',
    'Mode' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'Notify participants about changes' => '',
    'Participant removed.' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'The event has already ended.' => '',
    'Today' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You cannot invite participants!' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];
